BLAST FASTA files containing nucleotide or protein sequences, within a folder with a QuickBLAST instance. The files from the folder are selected with the extension parameter and BLAST'd against each other.
BLAST1Folder(
ptr,
input_folder,
extension,
out_folder,
out_format = NULL,
num_threads = 0L,
reciprocal_hits = FALSE,
min_batch_size = 0L,
verbose = TRUE
)(Rcpp::XPtr<QuickBLAST>) or (unsigned int) Pointer/ID of QuickBLAST instance
(string) Input folder
(string) Extension of files in folder.
(string) Ouput Folder (Required).
(string) Ouput Format. 'ipc'/'csv'/'parquet' (Optional) (Default: 'parquet').
(unsigned int) Number of threads. (Optional)
(bool) Perform Bi-directional (Reciprocal => query <-> subject) BLAST? (Default: FALSE) (Optional)
(unsigned int) Minimum batch size - Size of file write buffer (Optional).
(bool) Verbosity (Defulat: TRUE).
(bool) TRUE - on success, FALSE - Otherwise. (Results are not returned as R Lists to reduce overhead)
Only FASTA files are supported by this function, use BLAST2DBs() if inputs are BLAST DBs.
GetInstanceID(), GetQuickBLASTInstance(), BLAST2Files(), BLAST2Seqs(), BLAST2Folders(), BLAST1Folder(), RemoteBLAST()
blastp_inst <- QuickBLAST::CreateQuickBLASTInstance(
seq_type = 1,
strand = 0,
program = "blastp",
save_sequences = FALSE,
save_hsp_sequences = FALSE
)
#> Using blastp Defaults...
QuickBLAST::BLAST1Folder(
ptr = blastp_inst,
input_folder = system.file(
"extdata",
package = "QuickBLAST",
mustWork = TRUE
),
extension = "fasta",
out_folder = tempdir(),
out_format = "parquet",
reciprocal_hits = TRUE,
min_batch_size = 1024
)
#> [1] TRUE