R/RcppExports.R
isQuickBLASTLoaded.Rd
This function does nothing than check the connection between the R package and C++ libraries
isQuickBLASTLoaded()
String that successfully confirms when the package is loaded properly